@@ -10,6 +10,7 @@ from django.contrib import messages
 
 from polls.models import Choice, Poll, UserChoice
 from polls.forms import PollForm, PollVoteForm
+from polls.methods import get_poll_form, get_poll_vote_form
 
 class PollListView(ListView):
     template_name = 'polls/index.html'
@@ -30,10 +31,10 @@ class PollVoteView(FormView):
     
     def get(self, request, *args, **kwargs):
         self.pk = kwargs.get('pk')
-        self.form = PollVoteForm()
-        user = request.user
         poll = Poll.objects.get(pk=self.pk)
         
+        self.form = get_poll_vote_form(poll)
+        
         return super(PollVoteView, self).get(request, *args, **kwargs)
     
     def post(self, request, *args, **kwargs):
@@ -66,13 +67,9 @@ class PollVoteView(FormView):
         pk = self.pk
         
         instance = Poll.objects.get(pk=pk)
-            
-        form = self.form
-        
-        form.construct(instance)
         
         context['pk'] = pk
-        context['form'] = form
+        context['form'] = self.form
         context['instance'] = instance
         
         return context
@@ -91,11 +88,7 @@ class PollView(FormView):
         else:
             instance = None
         
-        form = PollForm(instance=instance)
-        
-        ChoiceFormSet = inlineformset_factory(Poll, Choice)
-        
-        formset = ChoiceFormSet(instance=instance)
+        form, formset = get_poll_form(instance, request)
         
         context = dict(form=form, formset=formset)
         
@@ -110,14 +103,10 @@ class PollView(FormView):
                 return HttpResponseRedirect('%s?%s' % (settings.LOGIN_URL, request.path))
         else:
             instance = None
-            
-        ChoiceFormSet = inlineformset_factory(Poll, Choice)
         
         data = request.POST
         
-        form = PollForm(data, instance=instance) if instance else PollForm(data)
-        form.instance.user = request.user
-        formset = ChoiceFormSet(data, instance=form.instance)
+        form, formset = get_poll_form(instance, request)
         
         if form.is_valid() and formset.is_valid():
             form.save()
